powered by
This function computes the test statistic and the p-value of Wald's test for the exponent parameter in EEP model.
asymptotic_eep(data, eta0, theta1, eta1)
This function returns the test statistic and the p-value of the Wald's test.
Observations.
To test if the exponent equals 1, the default for eta0 is et to be 1.
The unrestricted MLE of theta.
The unrestricted MLE of eta.
asymptotic_eep
sample1 = eep_sampling(200,eta = 1.1,theta = 3) theta1 = mle_search_eep(data = sample1)$theta eta1 = mle_search_eep(data = sample1)$eta asymptotic_eep(sample1,eta0 = 1,theta1,eta1)
Run the code above in your browser using DataLab