Learn R Programming

GEC (version 0.1.0)

eigp_nll: The EIGP Negative Log-likelihood Function.

Description

This function serves as the objective function for the Maximum Likelihood Estimation procedure for EIGP.

Usage

eigp_nll(x, m, data)

Value

A scalar that represents the negative loglikelihood of a EIGP sample given the model parameter and the data.

Arguments

x

Vector of parameters.

m

The number of data items less than the density change point.

data

Observations.

Details

eigp_nll

Examples

Run this code
eigp_nll(c(2,2),50,seq(1:100))

Run the code above in your browser using DataLab