Learn R Programming

GEC (version 0.1.0)

inv_gamma_eigp: The negative log density of a sample item if it follows inverse gamma in a EIGP model

Description

This function return the negative log density of a sample item if if it follows inverse gamma in a EIGP model.

Usage

inv_gamma_eigp(x, theta, eta)

Value

This function return the negative log density of a sample item if if it follows inverse gamma in a EIGP model.

Arguments

x

The value of a sample item.

theta

The location parameter for the base distribution (eta = 1). The value needs to be positive.

eta

The exponent parameter. The value provided needs to be positive.

Details

inv_gamma_eigp

Examples

Run this code
inv_gamma_eigp(1,5,2)

Run the code above in your browser using DataLab