Learn R Programming

GEC (version 0.1.0)

mle_eigp: Analytical solution of theta given eta in EIGP model.

Description

This function provides the analytical solution of theta for given eta EIGP model.

Usage

mle_eigp(s, m, n)

Value

This function returns the Maximum Likelihood Estimate of theta for a given eta.

Arguments

s

a numeric value the sum of log(1/x_i^eta), where i is from 1 to m.

m

m is the number of data items less than the density change point.

n

n is the sample size, n has to be greater than m.

Details

mle_eigp

Examples

Run this code
mle_eigp(5,2,5)

Run the code above in your browser using DataLab