Learn R Programming

GEC (version 0.1.0)

mle_iter_eep: Iteration function to find the analytical solution of theta given eta and data in EEP model.

Description

This function finds the analytical solution of theta given eta and data in EEP model.

Usage

mle_iter_eep(data, eta)

Value

This function returns the Maximum Likelihood Estimate of theta for a given eta with data.

Arguments

data

Observations.

eta

The exponent parameter. This value is greater than 0.

Details

mle_iter_eep

Examples

Run this code
mle_iter_eep(seq(1:100),2)

Run the code above in your browser using DataLab