Learn R Programming

GEC (version 0.1.0)

mle_search_eep: The grid search procedure for parameter estimation of EEP.

Description

This function find the parameter estimates of EEP throgh a grid search procedure.

Usage

mle_search_eep(eta_seq = seq(0.5, 10, by = 0.01), data)

Value

This function returns a data frame as the parameter estimates for EEP from grid search methods.

Arguments

eta_seq

A predefined range for eta values. The default is c(0.5,10,by = 0.01)

data

Observations.

Details

mle_search_eep

Examples

Run this code
sample1 = eep_sampling(200,eta = 2,theta = 3)
mle_search_eep(data = sample1)

Run the code above in your browser using DataLab