powered by
This function serves as the objective function for the Maximum Likelihood Estimation procedure for EIGP.
eigp_nll(x, m, data)
A scalar that represents the negative loglikelihood of a EIGP sample given the model parameter and the data.
Vector of parameters.
The number of data items less than the density change point.
Observations.
eigp_nll
eigp_nll(c(2,2),50,seq(1:100))
Run the code above in your browser using DataLab