inv_gamma_eigp: The negative log density of a sample item if it follows inverse gamma in a EIGP model
Description
This function return the negative log density of a sample item if if it follows inverse gamma in a EIGP model.
Usage
inv_gamma_eigp(x, theta, eta)
Value
This function return the negative log density of a sample item if if it follows inverse gamma in a EIGP model.
Arguments
- x
The value of a sample item.
- theta
The location parameter for the base distribution (eta = 1). The value needs to be positive.
- eta
The exponent parameter. The value provided needs to be positive.