powered by
This function provides the analytical solution of theta for given eta EIGP model.
mle_eigp(s, m, n)
This function returns the Maximum Likelihood Estimate of theta for a given eta.
a numeric value the sum of log(1/x_i^eta), where i is from 1 to m.
m is the number of data items less than the density change point.
n is the sample size, n has to be greater than m.
mle_eigp
mle_eigp(5,2,5)
Run the code above in your browser using DataLab