powered by
This function finds the analytical solution of theta given eta and data in EEP model.
mle_iter_eep(data, eta)
This function returns the Maximum Likelihood Estimate of theta for a given eta with data.
Observations.
The exponent parameter. This value is greater than 0.
mle_iter_eep
mle_iter_eep(seq(1:100),2)
Run the code above in your browser using DataLab