pareto_eep: The negative log density of a sample item if it follows Pareto in a EEP model
Description
This function return the negative log density of a sample item if if it follows Pareto in a EEP model.
Usage
pareto_eep(x, theta, eta)
Value
This function return the negative log density of a sample item if if it follows Pareto in a EEP model.
Arguments
- x
The value of a sample item.
- theta
The location parameter for the base distribution (eta = 1). The value needs to be positive.
- eta
The exponent parameter. The value provided needs to be positive.